/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 4.0.2
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package nl.stcorp.coda;

public enum ExpressionTypeEnum {
  coda_expression_boolean,
  coda_expression_integer,
  coda_expression_float,
  coda_expression_string,
  coda_expression_node,
  coda_expression_void;

  public final int swigValue() {
    return swigValue;
  }

  public static ExpressionTypeEnum swigToEnum(int swigValue) {
    ExpressionTypeEnum[] swigValues = ExpressionTypeEnum.class.getEnumConstants();
    if (swigValue < swigValues.length && swigValue >= 0 && swigValues[swigValue].swigValue == swigValue)
      return swigValues[swigValue];
    for (ExpressionTypeEnum swigEnum : swigValues)
      if (swigEnum.swigValue == swigValue)
        return swigEnum;
    throw new IllegalArgumentException("No enum " + ExpressionTypeEnum.class + " with value " + swigValue);
  }

  @SuppressWarnings("unused")
  private ExpressionTypeEnum() {
    this.swigValue = SwigNext.next++;
  }

  @SuppressWarnings("unused")
  private ExpressionTypeEnum(int swigValue) {
    this.swigValue = swigValue;
    SwigNext.next = swigValue+1;
  }

  @SuppressWarnings("unused")
  private ExpressionTypeEnum(ExpressionTypeEnum swigEnum) {
    this.swigValue = swigEnum.swigValue;
    SwigNext.next = this.swigValue+1;
  }

  private final int swigValue;

  private static class SwigNext {
    private static int next = 0;
  }
}

